@@ -152,9 +152,9 @@ async fn main() {
     let mut number = 0.0f32;
 
     loop {
-        clear_background(RED);
+        clear_background(GRAY);
 
-        root_ui().group(hash!(), vec2(100.0, 100.0), |ui| {
+        root_ui().group(hash!(), vec2(70.0, 100.0), |ui| {
             ui.label(None, "Window 1");
 
             if ui.button(None, "Skin 1") {
@@ -168,7 +168,7 @@ async fn main() {
             }
         });
         root_ui().same_line(0.);
-        root_ui().group(hash!(), vec2(100.0, 100.0), |ui| {
+        root_ui().group(hash!(), vec2(70.0, 100.0), |ui| {
             ui.label(None, "Window 2");
             if ui.button(None, "Skin 1") {
                 window2_skin = skin1.clone();
@@ -181,13 +181,9 @@ async fn main() {
             }
         });
 
-        root_ui().button(None, "Apply");
-        root_ui().same_line(0.);
-        root_ui().button(None, "aa");
-
         root_ui().push_skin(&window1_skin);
 
-        root_ui().window(hash!(), vec2(100., 150.), vec2(300., 300.), |ui| {
+        root_ui().window(hash!(), vec2(20., 250.), vec2(300., 300.), |ui| {
             widgets::Button::new("Play")
                 .position(vec2(65.0, 15.0))
                 .ui(ui);
@@ -202,7 +198,7 @@ async fn main() {
         root_ui().pop_skin();
 
         root_ui().push_skin(&window2_skin);
-        root_ui().window(hash!(), vec2(400., 300.), vec2(500., 200.), |ui| {
+        root_ui().window(hash!(), vec2(250., 20.), vec2(500., 200.), |ui| {
             ui.checkbox(hash!(), "Checkbox 1", &mut checkbox);
             ui.input_text(hash!(), "Text", &mut text);
             ui.drag(hash!(), "Drag", None, &mut number);
